@@ -3,7 +3,7 @@ import logging
 
 
 def setup_module(thismodulebypytest):
-    logging.debug('setup_module-')
+    logging.debug("setup_module-")
 
 
 def session_00000():
@@ -21,11 +21,11 @@ def session_00001():
 
 
 def test_1(capsys):
-    logging.debug('test_1-')
+    logging.debug("test_1-")
 
 
 def test_2(capsys):
-    logging.debug('test_2-')
+    logging.debug("test_2-")
 
 
 def session_00002():
@@ -36,8 +36,8 @@ def session_00002():
 
 
 def test_3(capsys):
-    logging.debug('test_3-')
+    logging.debug("test_3-")
 
 
 def teardown_module():
-    logging.debug('teardown_module-')
+    logging.debug("teardown_module-")
