@@ -2,8 +2,8 @@
 import re
 
 
-def remove_fenced_code_blocks(lines, fence='```'):
-    """"Return lines not starting with fence or between fences."""
+def remove_fenced_code_blocks(lines, fence="```"):
+    """ "Return lines not starting with fence or between fences."""
     skipping = False
     for line in lines:
         if skipping and line.startswith(fence):
@@ -18,40 +18,40 @@ def remove_fenced_code_blocks(lines, fence='```'):
             yield line
 
 
-heading_level = '## '    # note trailing space
+heading_level = "## "  # note trailing space
 
 
 def make_quick_links(filename, style=None):
-    """"Generate links for a quick links section."""
-    with open(filename, encoding='utf-8') as f:
+    """ "Generate links for a quick links section."""
+    with open(filename, encoding="utf-8") as f:
         lines = f.readlines()
-    lines = [line.rstrip() for line in lines]    # lose newlines
+    lines = [line.rstrip() for line in lines]  # lose newlines
     # README.md has fenced code blocks that enclose other
     # fenced code blocks.  The outer blocks use ~~~ as the fence.
     # Remove the outer fenced code blocks first.
-    lines = remove_fenced_code_blocks(lines, '~~~')
+    lines = remove_fenced_code_blocks(lines, "~~~")
     lines = remove_fenced_code_blocks(lines)
     links = []
     for line in lines:
         if line.startswith(heading_level):
-            title = line.replace(heading_level, '')
-            label = '[' + title + ']'
+            title = line.replace(heading_level, "")
+            label = "[" + title + "]"
             link = title.lower()
-            if style == 'github':
-                link = link.replace(' ', '-')
+            if style == "github":
+                link = link.replace(" ", "-")
             else:
                 # note- this only worked in the Sphinx 1.8.5 docs
-                some_punctuation = ','
-                link = re.sub('[' + some_punctuation + ']', '', link)
-                link = link.replace('-', ' ')
+                some_punctuation = ","
+                link = re.sub("[" + some_punctuation + "]", "", link)
+                link = link.replace("-", " ")
                 # convert runs of space to single dash
-                link = re.sub('[ ]+', '-', link)
+                link = re.sub("[ ]+", "-", link)
                 # remove runs of - at the start of a line
-                link = re.sub('^[-]+', '', link)
+                link = re.sub("^[-]+", "", link)
 
-            link = '(#' + link + ')'
+            link = "(#" + link + ")"
             links.append(label + link)
-    return ' |\n'.join(links)
+    return " |\n".join(links)
 
 
 # def make_sphinx_readme(readme_filename, sphinx_readme_filename):
@@ -65,12 +65,11 @@ def make_quick_links(filename, style=None):
 #         f2.write(sphinx_readme)
 
 
-if __name__ == '__main__':
-    text = make_quick_links('../README.md', style='github')
+if __name__ == "__main__":
+    text = make_quick_links("../README.md", style="github")
     print(text)
     print()
-    num_links = text.count('\n') + 1
-    print('created {} links, {} characters'.format(
-        num_links, len(text)))
+    num_links = text.count("\n") + 1
+    print("created {} links, {} characters".format(num_links, len(text)))
     # print('making README_sphinx.md...')
     # make_sphinx_readme('../README.md', '../README_sphinx.md')
